==> nui_core-0.0.127.tar.gz: lib/ui/nui_display_util.dart <==
import 'package:flutter/cupertino.dart';
import 'package:nui_core/color/nui_colors.dart';
import 'package:nui_core/model/screen_info.dart';
import 'package:flutter/services.dart';

class NUIOverlayStyle{
  NUIOverlayStyle({this.statusBarColor, this.navigationBarColor, this.darkStatusBarIcon, this.darkNavigationBarIcon, this.darkStatusBar});
  final Color statusBarColor;
  final Color navigationBarColor;
  final bool darkStatusBarIcon;
  final bool darkNavigationBarIcon;
  final bool darkStatusBar;
}

double screenWidth(BuildContext context){
  return NUIDisplayUtil.screenWidth(context);
}

double screenHeight(BuildContext context){
  return NUIDisplayUtil.screenHeight(context);
}

class NUIDisplayUtil{

  static List<NUIOverlayStyle> _overlayStyles = List();

  static double screenWidth(BuildContext context){
    return MediaQuery.of(context).size.width;
  }

  static Widget rotate({@required Widget view, @required double angle, Alignment alignment: Alignment.center}){
    return Transform.rotate(angle: angle, child: view, alignment: alignment);
  }

  static double screenHeight(BuildContext context){
    return MediaQuery.of(context).size.height;
  }

  static double statusBarHeight(BuildContext context){
    return MediaQuery.of(context).padding.top;
  }

  static ScreenInfo screenInfo(BuildContext context){
    final display = MediaQuery.of(context);
    final info = display.size;
    final width = info.width;
    final height = info.height;
    final statusBarHeight = display.padding.top;
    return ScreenInfo(width, height, statusBarHeight);
  }

  static void setStatusBarAttr({Color statusBarColor:NUIColors.NUITransparent, Color navigationBarColor:NUIColors.NUIShadowBlack, darkStatusBarIcon:false, darkNavigationBarIcon:false, darkStatusBar:false}){
    SystemChrome.setSystemUIOverlayStyle(SystemUiOverlayStyle(
        statusBarColor: statusBarColor ?? NUIColors.NUITransparent,
        systemNavigationBarColor: navigationBarColor ?? NUIColors.NUIShadowBlack,
        statusBarBrightness: (darkStatusBar ?? false) ? Brightness.dark : Brightness.light,
        systemNavigationBarIconBrightness: (darkNavigationBarIcon ?? false) ? Brightness.dark : Brightness.light,
        statusBarIconBrightness: (darkStatusBarIcon ?? false) ? Brightness.dark : Brightness.light
    ));
  }

  static void setStatusBarStyleAttr(NUIOverlayStyle style, {bool internal: false}){
    if(!internal) {
      _overlayStyles.add(style);
    }
    setStatusBarAttr(statusBarColor: style?.statusBarColor, navigationBarColor: style?.navigationBarColor, darkStatusBarIcon: style?.darkStatusBarIcon, darkNavigationBarIcon: style?.darkNavigationBarIcon, darkStatusBar: style?.darkStatusBar);
  }

  static void reverseStatusBarStyleAttr(){
    NUIOverlayStyle lastStyle;
    if(_overlayStyles.length > 1){
      _overlayStyles.removeLast();
    }
    if(_overlayStyles.isNotEmpty) {
      lastStyle = _overlayStyles.last;
    }
    if(lastStyle != null){
      setStatusBarStyleAttr(lastStyle, internal: true);
    }
  }

}

==> nui_core-1.0.4.tar.gz: lib/ui/nui_display_util.dart <==
import 'package:flutter/cupertino.dart';
import 'package:nui_core/color/nui_colors.dart';
import 'package:nui_core/model/screen_info.dart';
import 'package:flutter/services.dart';

class NUIOverlayStyle{
  NUIOverlayStyle({
    this.statusBarColor,
    this.navigationBarColor,
    this.darkStatusBarIcon = false,
    this.darkNavigationBarIcon = false,
    this.darkStatusBar = false
  });
  final Color? statusBarColor;
  final Color? navigationBarColor;
  final bool darkStatusBarIcon;
  final bool darkNavigationBarIcon;
  final bool darkStatusBar;
}

double screenWidth(BuildContext context){
  return NUIDisplayUtil.screenWidth(context);
}

double screenHeight(BuildContext context){
  return NUIDisplayUtil.screenHeight(context);
}

class NUIDisplayUtil{

  static List<NUIOverlayStyle> _overlayStyles = [];

  static double screenWidth(BuildContext context){
    return MediaQuery.of(context).size.width;
  }

  static Widget rotate({required Widget view, required double angle, Alignment alignment = Alignment.center}){
    return Transform.rotate(angle: angle, child: view, alignment: alignment);
  }

  static double screenHeight(BuildContext context){
    return MediaQuery.of(context).size.height;
  }

  static double statusBarHeight(BuildContext context){
    return MediaQuery.of(context).padding.top;
  }

  static ScreenInfo screenInfo(BuildContext context){
    final display = MediaQuery.of(context);
    final info = display.size;
    final width = info.width;
    final height = info.height;
    final statusBarHeight = display.padding.top;
    return ScreenInfo(width, height, statusBarHeight);
  }

  static void setStatusBarAttr({Color? statusBarColor = NUIColors.NUITransparent, Color? navigationBarColor = NUIColors.NUIShadowBlack, darkStatusBarIcon = false, darkNavigationBarIcon = false, darkStatusBar = false}){
    SystemChrome.setSystemUIOverlayStyle(SystemUiOverlayStyle(
        statusBarColor: statusBarColor,
        systemNavigationBarColor: navigationBarColor,
        statusBarBrightness: (darkStatusBar ?? false) ? Brightness.dark : Brightness.light,
        systemNavigationBarIconBrightness: (darkNavigationBarIcon ?? false) ? Brightness.dark : Brightness.light,
        statusBarIconBrightness: (darkStatusBarIcon ?? false) ? Brightness.dark : Brightness.light
    ));
  }

  static void setStatusBarStyleAttr(NUIOverlayStyle style, {bool internal: false}){
    if(!internal) {
      _overlayStyles.add(style);
    }
    setStatusBarAttr(statusBarColor: style.statusBarColor, navigationBarColor: style.navigationBarColor, darkStatusBarIcon: style.darkStatusBarIcon, darkNavigationBarIcon: style.darkNavigationBarIcon, darkStatusBar: style.darkStatusBar);
  }

  static void reverseStatusBarStyleAttr(){
    NUIOverlayStyle? lastStyle;
    if(_overlayStyles.length > 1){
      _overlayStyles.removeLast();
    }
    if(_overlayStyles.isNotEmpty) {
      lastStyle = _overlayStyles.last;
    }
    if(lastStyle != null){
      setStatusBarStyleAttr(lastStyle, internal: true);
    }
  }

}
